# monkay

[![PyPI - Version](https://img.shields.io/pypi/v/monkay.svg)](https://pypi.org/project/monkay)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/monkay.svg)](https://pypi.org/project/monkay)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```shell
pip install monkay
```

## License

`monkay` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
